Attribute VB_Name = "basOutlook"
Option Explicit
'*************************************************************************
'Items Command Bar
'Module: basOutlook
'Sample Outlook 2000 COM Add-in application
'Provided by Micro Eye, Inc.
'http://www.microeye.com
'You can modify this COM Add-in project to suit your own requirements
'No support is provided for this sample COM Add-in project
'Purpose: Demonstrate a simple COM Add-in built using Outlook 2000
'*************************************************************************
'Use this public Outlook Application variable in module code
'Be sure to dereference this object variable in UnInitHandler
Public golApp As Outlook.Application
Public gobjCDO As MAPI.Session

'*************************************************************
'Custom procedure: GetFolderPath(ByVal objFolder)
'Purpose: Return a string folder path for a MAPIFolder
'Argument: MAPIFolder object
'Usage: MsgBox "The Folder Path is " & GetFolderPath(objFldr)
'Returns: String representing Folder Path
'*************************************************************
Function GetFolderPath(ByVal objFolder) As String
    On Error Resume Next
    Dim strFolderPath As String
    Dim objChild As MAPIFolder
    Dim objParent As MAPIFolder
    strFolderPath = "\" & objFolder.Name
    Set objChild = objFolder
    Do Until Err <> 0
            Set objParent = objChild.Parent
            If Err <> 0 Then
                Exit Do
            End If
            strFolderPath = "\" & objParent.Name & strFolderPath
            Set objChild = objParent
    Loop
    GetFolderPath = strFolderPath
End Function

'******************************************************************************
'Custom procedure: OpenMAPIFolder(ByVal strPath)
'Purpose: Return a MAPIFolder from Path argument
'Argument: String representation of folder path
'Usage:
'Set objFldr=OpenMAPIFolder("\Public Folders\All Public Folders")
'Returns: MAPIFolder object
'******************************************************************************
Function OpenMAPIFolder(ByVal strPath) As MAPIFolder
    Dim objFldr As MAPIFolder
    Dim strDir As String
    Dim strName As String
    Dim i As Integer
    On Error Resume Next
    If Left(strPath, Len("\")) = "\" Then
            strPath = Mid(strPath, Len("\") + 1)
    Else
            Set objFldr = golApp.ActiveExplorer.CurrentFolder
    End If
    While strPath <> ""
            i = InStr(strPath, "\")
            If i Then
                strDir = Left(strPath, i - 1)
                strPath = Mid(strPath, i + Len("\"))
            Else
                strDir = strPath
                strPath = ""
            End If
            If objFldr Is Nothing Then
                Set objFldr = golApp.GetNamespace("MAPI").Folders(strDir)
            On Error GoTo 0
            Else
                Set objFldr = objFldr.Folders(strDir)
            End If
    Wend
    Set OpenMAPIFolder = objFldr
End Function

'******************************************************************************
'Custom procedure: GetFormDescriptions(strEntryID, strStoreID)
'Purpose: Return a variant array containing custom forms in folder
'Argument: Outlook Entry ID, Store ID
'Usage:
'Set avarArray = GetFormDescriptions(objFolder.EntryID, objFolder.StoreID)
'Returns: Variant Array
'******************************************************************************
Public Function GetFormDescriptions(strEntryID, strStoreID) As Variant
Dim objFolder As MAPI.Folder
Dim objMsgFilter As MAPI.MessageFilter
Dim colHiddenMsgs As MAPI.Messages
Dim objHiddenMsg As MAPI.Message
Dim avarArray As Variant
Dim intCount, intLoop As Integer
'MAPI Properties for FormDescription Hidden Messages
Const PR_HIDDEN_FORM = &H6803001E
Const PR_FORM_MESSAGECLASS = &H6800001E
Set objFolder = gobjCDO.GetFolder(strEntryID, strStoreID)
Set colHiddenMsgs = objFolder.HiddenMessages
'colHiddenMsgs.Sort CdoAscending, CdoPR_DISPLAY_NAME
If colHiddenMsgs.Count Then
    'Set a filter on messages collection
    Set objMsgFilter = colHiddenMsgs.Filter
    objMsgFilter.Type = "IPM.Microsoft.FolderDesign.FormsDescription"
    'Sort FormDescription collection on Display Name
    colHiddenMsgs.Sort CdoAscending, CdoPR_DISPLAY_NAME
    If colHiddenMsgs.Count Then
        'Count number of forms in folder excluding hidden forms
        For Each objHiddenMsg In colHiddenMsgs
            If Not (objHiddenMsg.Fields(PR_HIDDEN_FORM)) Then
                intCount = intCount + 1
            End If
        Next
        If intCount Then
            'Dimension variant array to hold forms
            ReDim avarArray(intCount - 1, 1)
            For Each objHiddenMsg In colHiddenMsgs
                If Not (objHiddenMsg.Fields(PR_HIDDEN_FORM)) Then
                    avarArray(intLoop, 0) = _
                    objHiddenMsg.Fields(CdoPR_DISPLAY_NAME)
                    avarArray(intLoop, 1) = _
                    objHiddenMsg.Fields(PR_FORM_MESSAGECLASS)
                    intLoop = intLoop + 1
                End If
            Next
            GetFormDescriptions = avarArray
        Else
            GetFormDescriptions = Empty
        End If
    Else
        GetFormDescriptions = Empty
    End If
End If
End Function

Sub LaunchWordMail()
    On Error Resume Next
    Dim wdApp As Word.Application
    Dim wdDoc As Word.Document
    Set wdApp = CreateObject("Word.Application")
    Set wdDoc = wdApp.Documents.Add(DocumentType:=wdNewEmailMessage)
    wdApp.Visible = True
    wdApp.ActiveWindow.EnvelopeVisible = True
End Sub

Sub LaunchExcelMail()
    On Error Resume Next
    Dim xlApp As Excel.Application
    Dim xlBook As Excel.Workbook
    Set xlApp = CreateObject("Excel.Application")
    Set xlBook = xlApp.Workbooks.Add
    xlApp.Visible = True
    xlBook.EnvelopeVisible = True
End Sub

Sub LaunchPowerPointMail()
    On Error Resume Next
    Dim pptApp As New PowerPoint.Application
    Dim pptPres As PowerPoint.Presentation
    Dim pptSlide As PowerPoint.Slide
    Set pptPres = pptApp.Presentations.Add
    Set pptSlide = pptPres.Slides.Add(1, ppLayoutTitle)
    pptApp.Visible = True
    pptPres.EnvelopeVisible = True
End Sub

Sub CreateMail()
    On Error Resume Next
    Dim oMsg As MailItem
    Set oMsg = golApp.CreateItem(olMailItem)
    oMsg.Display
End Sub

Sub CreateAppt()
    On Error Resume Next
    Dim oMsg As AppointmentItem
    Set oMsg = golApp.CreateItem(olAppointmentItem)
    oMsg.Display
End Sub

Sub CreateMtgRequest()
    On Error Resume Next
    Dim oMsg As AppointmentItem
    Set oMsg = golApp.CreateItem(olAppointmentItem)
    oMsg.MeetingStatus = olMeeting
    oMsg.Display
End Sub

Sub CreateContact()
    On Error Resume Next
    Dim oMsg As ContactItem
    Set oMsg = golApp.CreateItem(olContactItem)
    oMsg.Display
End Sub

Sub CreateDistList()
    On Error Resume Next
    Dim oMsg As DistListItem
    Set oMsg = golApp.CreateItem(olDistributionListItem)
    oMsg.Display
End Sub

Sub CreateJournal()
    On Error Resume Next
    Dim oMsg As JournalItem
    Set oMsg = golApp.CreateItem(olJournalItem)
    oMsg.Display
End Sub

Sub CreateTask()
    On Error Resume Next
    Dim oMsg As TaskItem
    Set oMsg = golApp.CreateItem(olTaskItem)
    oMsg.Display
End Sub

Sub CreateTaskRequest()
    On Error Resume Next
    Dim oMsg As TaskItem
    Set oMsg = golApp.CreateItem(olTaskItem)
    oMsg.Assign
    oMsg.Display
End Sub

Sub CreatePost()
    Dim objFolder As MAPIFolder
    On Error Resume Next
    Set objFolder = golApp.ActiveExplorer.CurrentFolder
    If objFolder Is Nothing Then Exit Sub 'handles File System
    Dim oMsg As PostItem
    Set oMsg = objFolder.Items.Add("IPM.Post")
    oMsg.Display
End Sub

Sub CreateNote()
    On Error Resume Next
    Dim oMsg As NoteItem
    Set oMsg = golApp.CreateItem(olNoteItem)
    oMsg.Display
End Sub

Sub CreateForm()
    On Error Resume Next
    Dim CBC As CommandBarControl
    Set CBC = golApp.ActiveExplorer.CommandBars.FindControl(ID:=1910)
    CBC.Execute
End Sub

Sub CreateDocument()
    On Error Resume Next
    Dim CBC As CommandBarControl
    Set CBC = golApp.ActiveExplorer.CommandBars.FindControl(ID:=2576)
    CBC.Execute
End Sub



